@@ -32,6 +32,12 @@
 #include <exception>
 #include <stdio.h>
 
+using std::pow;
+using std::fabs;
+using std::sqrt;
+using std::log;
+using std::exp;
+
 ////////////////////////////////////////////////////////////////////////////////
 // PolyaGamma //
 ////////////////////////////////////////////////////////////////////////////////
